Raiden Network
==============

.. image:: https://img.shields.io/pypi/pyversions/raiden.svg
    :target: https://raiden-network.readthedocs.io/en/stable/)
    :alt: Python 3.7
.. image:: https://badges.gitter.im/Join%20Chat.svg
    :target: https://gitter.im/raiden-network/raiden?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge
    :alt: Chat on Gitter

`Raiden Network documentation`_

.. _Raiden Network documentation: https://raiden-network.readthedocs.io/

The Raiden Network is an off-chain scaling solution, enabling near-instant, low-fee and scalable payments. It’s complementary to the Ethereum blockchain and works with any ERC20 compatible token.

The Raiden project is a work in progress. Its goal is to research state channel technology, define protocols and develop reference implementations.

For more information please visit https://raiden.network/.

Installation
------------

Please refer to the `Installation section`_ in the official docs.

.. _Installation section: https://raiden-network.readthedocs.io/en/stable/overview_and_guide.html#installation

Smart Contracts
---------------

The smart contracts are available in the `raiden-contracts`_ repo.

.. _raiden-contracts: https://github.com/raiden-network/raiden-contracts/
